@@ -2,7 +2,7 @@ package Geo::Distance;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 =encoding utf8
 
@@ -70,6 +70,8 @@ use Const::Fast;
 
 =head1 FORMULAS
 
+C<alt> - See L<GIS::Distance::ALT>.
+
 C<cos> - See L<GIS::Distance::Cosine>.
 
 C<gcd> - See L<GIS::Distance::GreatCircle>.
@@ -87,6 +89,7 @@ C<tv> - See L<GIS::Distance::Vincenty>.
 =cut
 
 const our %GEO_TO_GIS_FORMULA_MAP => (qw(
+    alt   ALT
     cos   Cosine
     gcd   GreatCircle
     hsin  Haversine
